==> codepipeline-api-0.10.0-sources.jar: software/amazon/awscdk/services/codepipeline/api/ActionProps.java <==
package software.amazon.awscdk.services.codepipeline.api;

/**
 * Construction properties of the low-level {@link Action Action class}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-27T21:46:12.149Z")
public interface ActionProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.codepipeline.api.CommonActionProps {
    software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds getArtifactBounds();
    void setArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value);
    software.amazon.awscdk.services.codepipeline.api.ActionCategory getCategory();
    void setCategory(final software.amazon.awscdk.services.codepipeline.api.ActionCategory value);
    java.lang.String getProvider();
    void setProvider(final java.lang.String value);
    java.lang.Object getConfiguration();
    void setConfiguration(final java.lang.Object value);
    java.lang.String getOwner();
    void setOwner(final java.lang.String value);
    java.lang.String getVersion();
    void setVersion(final java.lang.String value);

    /**
     * @return a {@link Builder} of {@link ActionProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ActionProps}
     */
    final class Builder {
        private software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds _artifactBounds;
        private software.amazon.awscdk.services.codepipeline.api.ActionCategory _category;
        private java.lang.String _provider;
        @javax.annotation.Nullable
        private java.lang.Object _configuration;
        @javax.annotation.Nullable
        private java.lang.String _owner;
        @javax.annotation.Nullable
        private java.lang.String _version;
        private software.amazon.awscdk.services.codepipeline.api.IStage _stage;

        /**
         * Sets the value of ArtifactBounds
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value) {
            this._artifactBounds = java.util.Objects.requireNonNull(value, "artifactBounds is required");
            return this;
        }
        /**
         * Sets the value of Category
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withCategory(final software.amazon.awscdk.services.codepipeline.api.ActionCategory value) {
            this._category = java.util.Objects.requireNonNull(value, "category is required");
            return this;
        }
        /**
         * Sets the value of Provider
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withProvider(final java.lang.String value) {
            this._provider = java.util.Objects.requireNonNull(value, "provider is required");
            return this;
        }
        /**
         * Sets the value of Configuration
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withConfiguration(@javax.annotation.Nullable final java.lang.Object value) {
            this._configuration = value;
            return this;
        }
        /**
         * Sets the value of Owner
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withOwner(@javax.annotation.Nullable final java.lang.String value) {
            this._owner = value;
            return this;
        }
        /**
         * Sets the value of Version
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withVersion(@javax.annotation.Nullable final java.lang.String value) {
            this._version = value;
            return this;
        }
        /**
         * Sets the value of Stage
         * @param value The Pipeline Stage to add this Action to.
         * @return {@code this}
         */
        public Builder withStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
            this._stage = java.util.Objects.requireNonNull(value, "stage is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ActionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public ActionProps build() {
            return new ActionProps() {
                private software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds $artifactBounds = java.util.Objects.requireNonNull(_artifactBounds, "artifactBounds is required");
                private software.amazon.awscdk.services.codepipeline.api.ActionCategory $category = java.util.Objects.requireNonNull(_category, "category is required");
                private java.lang.String $provider = java.util.Objects.requireNonNull(_provider, "provider is required");
                @javax.annotation.Nullable
                private java.lang.Object $configuration = _configuration;
                @javax.annotation.Nullable
                private java.lang.String $owner = _owner;
                @javax.annotation.Nullable
                private java.lang.String $version = _version;
                private software.amazon.awscdk.services.codepipeline.api.IStage $stage = java.util.Objects.requireNonNull(_stage, "stage is required");

                @Override
                public software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds getArtifactBounds() {
                    return this.$artifactBounds;
                }

                @Override
                public void setArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value) {
                    this.$artifactBounds = java.util.Objects.requireNonNull(value, "artifactBounds is required");
                }

                @Override
                public software.amazon.awscdk.services.codepipeline.api.ActionCategory getCategory() {
                    return this.$category;
                }

                @Override
                public void setCategory(final software.amazon.awscdk.services.codepipeline.api.ActionCategory value) {
                    this.$category = java.util.Objects.requireNonNull(value, "category is required");
                }

                @Override
                public java.lang.String getProvider() {
                    return this.$provider;
                }

                @Override
                public void setProvider(final java.lang.String value) {
                    this.$provider = java.util.Objects.requireNonNull(value, "provider is required");
                }

                @Override
                public java.lang.Object getConfiguration() {
                    return this.$configuration;
                }

                @Override
                public void setConfiguration(@javax.annotation.Nullable final java.lang.Object value) {
                    this.$configuration = value;
                }

                @Override
                public java.lang.String getOwner() {
                    return this.$owner;
                }

                @Override
                public void setOwner(@javax.annotation.Nullable final java.lang.String value) {
                    this.$owner = value;
                }

                @Override
                public java.lang.String getVersion() {
                    return this.$version;
                }

                @Override
                public void setVersion(@javax.annotation.Nullable final java.lang.String value) {
                    this.$version = value;
                }

                @Override
                public software.amazon.awscdk.services.codepipeline.api.IStage getStage() {
                    return this.$stage;
                }

                @Override
                public void setStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
                    this.$stage = java.util.Objects.requireNonNull(value, "stage is required");
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.codepipeline.api.ActionProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        @Override
        public software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds getArtifactBounds() {
            return this.jsiiGet("artifactBounds", software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds.class);
        }

        @Override
        public void setArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value) {
            this.jsiiSet("artifactBounds", java.util.Objects.requireNonNull(value, "artifactBounds is required"));
        }

        @Override
        public software.amazon.awscdk.services.codepipeline.api.ActionCategory getCategory() {
            return this.jsiiGet("category", software.amazon.awscdk.services.codepipeline.api.ActionCategory.class);
        }

        @Override
        public void setCategory(final software.amazon.awscdk.services.codepipeline.api.ActionCategory value) {
            this.jsiiSet("category", java.util.Objects.requireNonNull(value, "category is required"));
        }

        @Override
        public java.lang.String getProvider() {
            return this.jsiiGet("provider", java.lang.String.class);
        }

        @Override
        public void setProvider(final java.lang.String value) {
            this.jsiiSet("provider", java.util.Objects.requireNonNull(value, "provider is required"));
        }

        @Override
        @javax.annotation.Nullable
        public java.lang.Object getConfiguration() {
            return this.jsiiGet("configuration", java.lang.Object.class);
        }

        @Override
        public void setConfiguration(@javax.annotation.Nullable final java.lang.Object value) {
            this.jsiiSet("configuration", value);
        }

        @Override
        @javax.annotation.Nullable
        public java.lang.String getOwner() {
            return this.jsiiGet("owner", java.lang.String.class);
        }

        @Override
        public void setOwner(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("owner", value);
        }

        @Override
        @javax.annotation.Nullable
        public java.lang.String getVersion() {
            return this.jsiiGet("version", java.lang.String.class);
        }

        @Override
        public void setVersion(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("version", value);
        }

        /**
         * The Pipeline Stage to add this Action to.
         */
        @Override
        public software.amazon.awscdk.services.codepipeline.api.IStage getStage() {
            return this.jsiiGet("stage", software.amazon.awscdk.services.codepipeline.api.IStage.class);
        }

        /**
         * The Pipeline Stage to add this Action to.
         */
        @Override
        public void setStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
            this.jsiiSet("stage", java.util.Objects.requireNonNull(value, "stage is required"));
        }
    }
}

==> codepipeline-api-0.11.0-sources.jar: software/amazon/awscdk/services/codepipeline/api/ActionProps.java <==
package software.amazon.awscdk.services.codepipeline.api;

/**
 * Construction properties of the low-level {@link Action Action class}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.7 (build b1c202b)", date = "2018-10-11T18:02:06.197Z")
public interface ActionProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.codepipeline.api.CommonActionProps, software.amazon.awscdk.services.codepipeline.api.CommonActionConstructProps {
    software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds getArtifactBounds();
    void setArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value);
    software.amazon.awscdk.services.codepipeline.api.ActionCategory getCategory();
    void setCategory(final software.amazon.awscdk.services.codepipeline.api.ActionCategory value);
    java.lang.String getProvider();
    void setProvider(final java.lang.String value);
    java.lang.Object getConfiguration();
    void setConfiguration(final java.lang.Object value);
    java.lang.String getOwner();
    void setOwner(final java.lang.String value);
    java.lang.String getVersion();
    void setVersion(final java.lang.String value);

    /**
     * @return a {@link Builder} of {@link ActionProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ActionProps}
     */
    final class Builder {
        private software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds _artifactBounds;
        private software.amazon.awscdk.services.codepipeline.api.ActionCategory _category;
        private java.lang.String _provider;
        @javax.annotation.Nullable
        private java.lang.Object _configuration;
        @javax.annotation.Nullable
        private java.lang.String _owner;
        @javax.annotation.Nullable
        private java.lang.String _version;
        @javax.annotation.Nullable
        private java.lang.Number _runOrder;
        private software.amazon.awscdk.services.codepipeline.api.IStage _stage;

        /**
         * Sets the value of ArtifactBounds
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value) {
            this._artifactBounds = java.util.Objects.requireNonNull(value, "artifactBounds is required");
            return this;
        }
        /**
         * Sets the value of Category
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withCategory(final software.amazon.awscdk.services.codepipeline.api.ActionCategory value) {
            this._category = java.util.Objects.requireNonNull(value, "category is required");
            return this;
        }
        /**
         * Sets the value of Provider
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withProvider(final java.lang.String value) {
            this._provider = java.util.Objects.requireNonNull(value, "provider is required");
            return this;
        }
        /**
         * Sets the value of Configuration
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withConfiguration(@javax.annotation.Nullable final java.lang.Object value) {
            this._configuration = value;
            return this;
        }
        /**
         * Sets the value of Owner
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withOwner(@javax.annotation.Nullable final java.lang.String value) {
            this._owner = value;
            return this;
        }
        /**
         * Sets the value of Version
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withVersion(@javax.annotation.Nullable final java.lang.String value) {
            this._version = value;
            return this;
        }
        /**
         * Sets the value of RunOrder
         * @param value The runOrder property for this Action.
RunOrder determines the relative order in which multiple Actions in the same Stage execute.
         * @return {@code this}
         */
        public Builder withRunOrder(@javax.annotation.Nullable final java.lang.Number value) {
            this._runOrder = value;
            return this;
        }
        /**
         * Sets the value of Stage
         * @param value The Pipeline Stage to add this Action to.
         * @return {@code this}
         */
        public Builder withStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
            this._stage = java.util.Objects.requireNonNull(value, "stage is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ActionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public ActionProps build() {
            return new ActionProps() {
                private software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds $artifactBounds = java.util.Objects.requireNonNull(_artifactBounds, "artifactBounds is required");
                private software.amazon.awscdk.services.codepipeline.api.ActionCategory $category = java.util.Objects.requireNonNull(_category, "category is required");
                private java.lang.String $provider = java.util.Objects.requireNonNull(_provider, "provider is required");
                @javax.annotation.Nullable
                private java.lang.Object $configuration = _configuration;
                @javax.annotation.Nullable
                private java.lang.String $owner = _owner;
                @javax.annotation.Nullable
                private java.lang.String $version = _version;
                @javax.annotation.Nullable
                private java.lang.Number $runOrder = _runOrder;
                private software.amazon.awscdk.services.codepipeline.api.IStage $stage = java.util.Objects.requireNonNull(_stage, "stage is required");

                @Override
                public software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds getArtifactBounds() {
                    return this.$artifactBounds;
                }

                @Override
                public void setArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value) {
                    this.$artifactBounds = java.util.Objects.requireNonNull(value, "artifactBounds is required");
                }

                @Override
                public software.amazon.awscdk.services.codepipeline.api.ActionCategory getCategory() {
                    return this.$category;
                }

                @Override
                public void setCategory(final software.amazon.awscdk.services.codepipeline.api.ActionCategory value) {
                    this.$category = java.util.Objects.requireNonNull(value, "category is required");
                }

                @Override
                public java.lang.String getProvider() {
                    return this.$provider;
                }

                @Override
                public void setProvider(final java.lang.String value) {
                    this.$provider = java.util.Objects.requireNonNull(value, "provider is required");
                }

                @Override
                public java.lang.Object getConfiguration() {
                    return this.$configuration;
                }

                @Override
                public void setConfiguration(@javax.annotation.Nullable final java.lang.Object value) {
                    this.$configuration = value;
                }

                @Override
                public java.lang.String getOwner() {
                    return this.$owner;
                }

                @Override
                public void setOwner(@javax.annotation.Nullable final java.lang.String value) {
                    this.$owner = value;
                }

                @Override
                public java.lang.String getVersion() {
                    return this.$version;
                }

                @Override
                public void setVersion(@javax.annotation.Nullable final java.lang.String value) {
                    this.$version = value;
                }

                @Override
                public java.lang.Number getRunOrder() {
                    return this.$runOrder;
                }

                @Override
                public void setRunOrder(@javax.annotation.Nullable final java.lang.Number value) {
                    this.$runOrder = value;
                }

                @Override
                public software.amazon.awscdk.services.codepipeline.api.IStage getStage() {
                    return this.$stage;
                }

                @Override
                public void setStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
                    this.$stage = java.util.Objects.requireNonNull(value, "stage is required");
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.codepipeline.api.ActionProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        @Override
        public software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds getArtifactBounds() {
            return this.jsiiGet("artifactBounds", software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds.class);
        }

        @Override
        public void setArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value) {
            this.jsiiSet("artifactBounds", java.util.Objects.requireNonNull(value, "artifactBounds is required"));
        }

        @Override
        public software.amazon.awscdk.services.codepipeline.api.ActionCategory getCategory() {
            return this.jsiiGet("category", software.amazon.awscdk.services.codepipeline.api.ActionCategory.class);
        }

        @Override
        public void setCategory(final software.amazon.awscdk.services.codepipeline.api.ActionCategory value) {
            this.jsiiSet("category", java.util.Objects.requireNonNull(value, "category is required"));
        }

        @Override
        public java.lang.String getProvider() {
            return this.jsiiGet("provider", java.lang.String.class);
        }

        @Override
        public void setProvider(final java.lang.String value) {
            this.jsiiSet("provider", java.util.Objects.requireNonNull(value, "provider is required"));
        }

        @Override
        @javax.annotation.Nullable
        public java.lang.Object getConfiguration() {
            return this.jsiiGet("configuration", java.lang.Object.class);
        }

        @Override
        public void setConfiguration(@javax.annotation.Nullable final java.lang.Object value) {
            this.jsiiSet("configuration", value);
        }

        @Override
        @javax.annotation.Nullable
        public java.lang.String getOwner() {
            return this.jsiiGet("owner", java.lang.String.class);
        }

        @Override
        public void setOwner(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("owner", value);
        }

        @Override
        @javax.annotation.Nullable
        public java.lang.String getVersion() {
            return this.jsiiGet("version", java.lang.String.class);
        }

        @Override
        public void setVersion(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("version", value);
        }

        /**
         * The runOrder property for this Action.
         * RunOrder determines the relative order in which multiple Actions in the same Stage execute.
         * @default 1
         * @see https://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Number getRunOrder() {
            return this.jsiiGet("runOrder", java.lang.Number.class);
        }

        /**
         * The runOrder property for this Action.
         * RunOrder determines the relative order in which multiple Actions in the same Stage execute.
         * @default 1
         * @see https://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html
         */
        @Override
        public void setRunOrder(@javax.annotation.Nullable final java.lang.Number value) {
            this.jsiiSet("runOrder", value);
        }

        /**
         * The Pipeline Stage to add this Action to.
         */
        @Override
        public software.amazon.awscdk.services.codepipeline.api.IStage getStage() {
            return this.jsiiGet("stage", software.amazon.awscdk.services.codepipeline.api.IStage.class);
        }

        /**
         * The Pipeline Stage to add this Action to.
         */
        @Override
        public void setStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
            this.jsiiSet("stage", java.util.Objects.requireNonNull(value, "stage is required"));
        }
    }
}
